from setuptools import setup

setup(name='testmz',
      version='0.1',
      description='The first python test package',
      url='http://github.com/mudassir21/server',
      author='Mudassir Zakaria',
      author_email='mudassir21bd@gmail.com',
      license='MIT',
      packages=['testmz'],
      zip_safe=False)